# ![mig3-client](https://repository-images.githubusercontent.com/183148001/d7c73680-6eaf-11e9-88b4-269c8d788541)
## *mig3-client*: Submit your results to a mig3 service.

[![Codacy Quality Badge](https://api.codacy.com/project/badge/Grade/8fbaac0868ee4261915b7c48ba8ee881)](https://app.codacy.com/app/mverteuil/mig3?utm_source=github.com&utm_medium=referral&utm_content=mverteuil/mig3-client&utm_campaign=Badge_Grade_Dashboard)
[![Codacy Coverage Badge](https://api.codacy.com/project/badge/Coverage/fcd5f70f0c294c948c70910456661093)](https://www.codacy.com/app/mverteuil/mig3-client?utm_source=github.com&utm_medium=referral&utm_content=mverteuil/mig3-client&utm_campaign=Badge_Coverage)
[![Build Status](https://travis-ci.com/mverteuil/mig3-client.svg?branch=master)](https://travis-ci.com/mverteuil/mig3-client)
![Supported Python Versions](https://img.shields.io/pypi/pyversions/mig3-client.svg)
[![Project License](https://img.shields.io/pypi/l/mig3-client.svg?color=blue)](https://github.com/mverteuil/mig3-client/blob/master/LICENSE)
[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2Fmverteuil%2Fmig3-client.svg?type=shield)](https://app.fossa.com/projects/git%2Bgithub.com%2Fmverteuil%2Fmig3-client?ref=badge_shield)
![Project Status](https://img.shields.io/pypi/status/mig3-client.svg)
[![PyPI version](https://img.shields.io/pypi/v/mig3-client.svg)](https://badge.fury.io/py/mig3-client)
[![PyPI downloads](https://img.shields.io/pypi/dm/mig3-client.svg?color=darklime)](https://pypi.org/project/mig3-client/)
[![Manpower](https://img.shields.io/github/contributors/mverteuil/mig3-client.svg?color=red&label=manpower)](https://github.com/mverteuil/mig3-client/graphs/contributors)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/python/black)
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fmverteuil%2Fmig3-client.svg?type=shield)](https://app.fossa.io/projects/git%2Bgithub.com%2Fmverteuil%2Fmig3-client?ref=badge_shield)

## See Also

-   [mig3](https://github.com/mverteuil/mig3-client): Detect regressions in your python3 migration!

## Basic setup

Install it:
```
$ pip install mig3-client
```

Run the application:
```
$ mig3 --help
```

## Developer setup

Install dependencies:
```
$ poetry install
```

To run the tests for the current environment:
```
$ poetry shell
$ py.test
```

To run the tests for all environments:
```
$ tox
```

## License

[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fmverteuil%2Fmig3-client.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fmverteuil%2Fmig3-client?ref=badge_large)
